@@ -51,36 +51,41 @@ class Insight_Definition:
             self.app_url = "https://app.askdata.com/"
 
 
-    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, texts:dict={}, charts:list=[]):
+    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[]):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
-            self.edit_widget(widget_id, widget_type,query_ids, settings, texts, charts)
+            self.edit_widget(widget_id, widget_type,query_ids, settings, values, texts, charts)
         return widget_id
 
-    def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, texts:dict={}, charts:list=[]):
+    def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
 
         columns = self.__get_columns(query_ids)
+
         settings = {}
         for field in field_codes.keys():
+            found = False
             for column in columns:
                 if(column["code"] in field_codes[field]):
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
                            if(str(column["id"]).startswith(query)):
-                               settings[field + "_id"] = column["id"]
+                               settings[field + "_id"] = column["code"]
+                               found = True
                                break
                            else:
                                continue
                         else:
-                            settings[field + "_id"] = column["id"]
+                            found = True
+                            settings[field + "_id"] = column["code"]
                             break
-                #Case when a value that is not a column is passed
-                else:
-                    settings[field + "_id"] = field_codes[field]
 
+        for key in values.keys():
+            settings[key] = values[key]
+
+        print(settings)
         body = {
             "id" : widget_id,
             "type": "widget",
