@@ -73,11 +73,10 @@ class Condition:
     operator: Union[SQLOperator, TimeOperator, str]
     value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
-    vuntil: Optional[List[Union[float, str]]] = None
     steps: Optional[str] = None
     interval: Optional[str] = None
     direction: Optional[Union[PeriodOperator, str]] = None
-    exclusion: Optional[bool] = None
+    negate: Optional[bool] = None
 
     def __repr__(self):
         vars = []
@@ -87,13 +86,7 @@ class Condition:
             formatted_value = "( " + ", ".join(vars) + " )"
         else:
             formatted_value = None
-        vuntils = []
-        if self.vuntil is not None:
-            for vunt in self.vuntil:
-                vuntils.append(str(vunt))
-            formatted_vuntil = "( " + ", ".join(vuntils) + " )"
-        else:
-            formatted_vuntil = None
+
         if isinstance(self.operator, str):
             operator = self.operator
         else:
@@ -117,19 +110,11 @@ class Condition:
                 field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
         else:
             field_with_agg = field_with_agg
-        if formatted_value is not None and formatted_vuntil is None and self.direction is None:
+        if formatted_value is not None and self.direction is None:
             where_condition = (
                     field_with_agg + " " + operator + " " + str(formatted_value)
             )
-        elif formatted_value is not None and formatted_vuntil is not None and self.direction is None:
-            where_condition = (
-                    field_with_agg + " " + operator + " " + str(formatted_value) + " " + str(formatted_vuntil)
-            )
-        elif formatted_value is None and formatted_vuntil is not None and self.direction is None:
-            where_condition = (
-                    field_with_agg + " " + operator + " " + str(formatted_vuntil)
-            )
-        elif formatted_value is None and formatted_vuntil is None and self.direction is not None:
+        elif formatted_value is None and self.direction is not None:
             if isinstance(self.direction, PeriodOperator):
                 direction = self.direction.name
             else:
@@ -278,10 +263,15 @@ class Query:
 
 @dataclass
 class SmartQuery:
-    queries: List[Query]
+    queries: Optional[List[Query]] = None
     components: Optional[List[Union[ChartComponent, MapComponent, QueryComponent, Component]]] = None
     javascript: Optional[List[str]] = None
 
+    def __init__(self, queries=None, components=None, javascript=None):
+        self.queries = queries
+        self.components = components
+        self.javascript = javascript
+
     @staticmethod
     def _get_tokens():
         f = open(os.path.join(os.path.dirname(__file__), "askdata_config", "compression_tokens.json"))
